==> futureagi-0.5.1-py3-none-any.whl: fi/integrations/otel/frameworks/anthropic/examples/chat_completions.py <==
import instructor
from openai import OpenAI
from pydantic import BaseModel

from fi.integrations.otel import InstructorInstrumentor, register
from fi.integrations.otel.types import (
    EvalName,
    EvalSpanKind,
    EvalTag,
    EvalTagType,
    ProjectType,
)

# Configure trace provider with custom evaluation tags
eval_tags = [
    EvalTag(
        eval_name=EvalName.DETERMINISTIC_EVALS,
        value=EvalSpanKind.TOOL,
        type=EvalTagType.OBSERVATION_SPAN,
        config={
            "multi_choice": False,
            "choices": ["Yes", "No"],
            "rule_prompt": "Evaluate if the response is correct",
        },
    )
]

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_type=ProjectType.EXPERIMENT,
    project_name="Future_AGI",
    project_version_name="v1",
    eval_tags=eval_tags,
)


# Define the output structure
class UserInfo(BaseModel):
    name: str
    age: int


# Patch the OpenAI clientos
client = instructor.patch(client=OpenAI())

InstructorInstrumentor().instrument(tracer_provider=trace_provider)

# Extract structured data from natural language
user_info = client.chat.completions.create(
    model="gpt-3.5-turbo",
    response_model=UserInfo,
    messages=[
        {
            "role": "system",
            "content": "Extract the name and age from the text and return them in a structured format.",
        },
        {"role": "user", "content": "John Doe is nine years old."},
    ],
)

print(user_info, type(user_info))

==> futureagi-0.5.5-py3-none-any.whl: fi/integrations/otel/frameworks/anthropic/examples/chat_completions.py <==
import instructor
from openai import OpenAI
from pydantic import BaseModel

from fi.integrations.otel import InstructorInstrumentor, register
from fi.integrations.otel.fi_types import (
    EvalName,
    EvalSpanKind,
    EvalTag,
    EvalTagType,
    ProjectType,
)

# Configure trace provider with custom evaluation tags
eval_tags = [
    EvalTag(
        eval_name=EvalName.DETERMINISTIC_EVALS,
        value=EvalSpanKind.TOOL,
        type=EvalTagType.OBSERVATION_SPAN,
        config={
            "multi_choice": False,
            "choices": ["Yes", "No"],
            "rule_prompt": "Evaluate if the response is correct",
        },
        custom_eval_name="<custom_eval_name>",
    )
]

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_type=ProjectType.EXPERIMENT,
    eval_tags=eval_tags,
    project_name="FUTURE_AGI",
    project_version_name="v1",
)


# Define the output structure
class UserInfo(BaseModel):
    name: str
    age: int


# Patch the OpenAI clientos
client = instructor.patch(client=OpenAI())

InstructorInstrumentor().instrument(tracer_provider=trace_provider)

# Extract structured data from natural language
user_info = client.chat.completions.create(
    model="gpt-3.5-turbo",
    response_model=UserInfo,
    messages=[
        {
            "role": "system",
            "content": "Extract the name and age from the text and return them in a structured format.",
        },
        {"role": "user", "content": "John Doe is nine years old."},
    ],
)

print(user_info, type(user_info))
